# Masking

Mask primitives, boolean operations, and the mask application pipeline.

## Mask (ABC)

::: pymotion.masking.Mask

## MaskOp

::: pymotion.masking.MaskOp

## MaskGroup

::: pymotion.masking.MaskGroup

## BezierMask

::: pymotion.masking.BezierMask

## BezierPoint

::: pymotion.masking.BezierPoint

## LinearGradientMask

::: pymotion.masking.LinearGradientMask

## RadialGradientMask

::: pymotion.masking.RadialGradientMask

## TrackMatte

::: pymotion.masking.TrackMatte

## TextMask

::: pymotion.masking.TextMask
